Module error_handling

Module error_handling 

Error handling

Various components can return errors. Usually these errors are caused by logic errors, malformed input, or network issues.

When a component returns an error, usually the error is then returned by all parent components until being returned as the result of the task.

However, sometimes errors can be recovered from and/or safely ignored.

Modules

first_not_error
First not error
try_else
Try else